==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property line Indicates if the file should be read as a json object per line.
 */
public data class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs(
    public val line: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs> {
    override fun toJava():
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.builder()
            .line(line?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs].
 */
@PulumiTagMarker
public class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgsBuilder
internal constructor() {
    private var line: Output<Boolean>? = null

    /**
     * @param value Indicates if the file should be read as a json object per line.
     */
    @JvmName("phmfaanaoxhpdmng")
    public suspend fun line(`value`: Output<Boolean>) {
        this.line = value
    }

    /**
     * @param value Indicates if the file should be read as a json object per line.
     */
    @JvmName("qeiwgwjltnufembq")
    public suspend fun line(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.line = mapped
    }

    internal fun build():
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs =
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs(
            line = line,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property line Indicates if the file should be read as a json object per line.
 */
public data class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs(
    public val line: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs =
        com.pulumi.aws.sagemaker.inputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs.builder()
            .line(line?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs].
 */
@PulumiTagMarker
public class
DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgsBuilder
internal constructor() {
    private var line: Output<Boolean>? = null

    /**
     * @param value Indicates if the file should be read as a json object per line.
     */
    @JvmName("opaveygqavggqlsh")
    public suspend fun line(`value`: Output<Boolean>) {
        this.line = value
    }

    /**
     * @param value Indicates if the file should be read as a json object per line.
     */
    @JvmName("lwvbomiudfdeeyet")
    public suspend fun line(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.line = mapped
    }

    internal fun build(): DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs =
        DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJsonArgs(
            line = line,
        )
}
